/* Arbitrary precision arithmetics in C-XSC
   ========================================

Copyright (C) 2010-11 Wiss. Rechnen/Softwaretechnologie
                      Universitaet Wuppertal, Germany   

**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Library General Public
**  License as published by the Free Software Foundation; either
**  version 2 of the License, or (at your option) any later version.
**
**  This library is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
**  Library General Public License for more details.
**
**  You should have received a copy of the GNU Library General Public
**  License along with this library; if not, write to the Free
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

//Name of file: example_main.cpp  
// Compute enclosures of sin(z)^2 + cos(z)^2 - 1 
// for z= 1/3 using different precision settings.

#include <iostream>
#include "mpficlass.hpp" //arbitrary precison intervals

using namespace MPFI;    //namespace of new package
using namespace cxsc;
using namespace std;

#define MP MpfiClass //MP is a short notation for data type

int main(){
  
  MP x; //argument of formula
  MP r; //result (enclosure of value(s) of formula) 

  for (int step=1; step<=6; step++) {
    
    //doubling the precision in each step
    MP::SetCurrPrecision( 2*MP::GetCurrPrecision( ) );  
    
    cout << "Step " << step << ", precision " 
         << MP::GetCurrPrecision( ) << " bits:" << endl;
	 
    x= MP(1)/3; //enclosure of 1/3= 0.33333...

    r= sqr(sin(x)) + sqr(cos(x)) - 1;  //interval r must contain 0
    cout << "   r: " << r << endl;
    
  }
  return 0;
}
/* Program output:

Step 1, precision 106 bits:
   r: [-2.46520e-32,2.46520e-32]
Step 2, precision 212 bits:
   r: [-1.51930e-64,6.07717e-64]
Step 3, precision 424 bits:
   r: [-6.92474e-128,4.61649e-128]
Step 4, precision 848 bits:
   r: [-1.06560e-255,2.13120e-255]
Step 5, precision 1696 bits:
   r: [-5.67751e-511,5.67751e-511]
Step 6, precision 3392 bits:
   r: [-2.41756e-1021,1.61171e-1021]

*/
